from fastapi import APIRouter
from fastapi.responses import StreamingResponse

from aiconsole.aic_types import ChatWithAgentAndMaterials, ExecutionModeContext
from aiconsole.agents.agents import agents
from aiconsole.utils.connection_manager import ErrorWSMessage, connection_manager

router = APIRouter()


@router.post("/execute")
async def execute(chat: ChatWithAgentAndMaterials) -> StreamingResponse:
    try:
        agent = agents.agents[chat.agent_id]

        context = ExecutionModeContext(
            messages=chat.messages,
            agent=agent,
            relevant_materials=chat.relevant_materials,
            gpt_mode=agent.gpt_mode,
        )

        return StreamingResponse(
            agent.execution_mode(context), media_type="text/event-stream"
        )
    except Exception as e:
        await connection_manager.send_message(chat.id, ErrorWSMessage(error=str(e)))
        raise e
    
