import json
from aiconsole.aic_types import AICMessage
from aiconsole.gpt.gpt_types import GPTMessage


from typing import List

def convert_message(message: AICMessage) -> List[GPTMessage]:
    content = message.content
    function_call = None
    name = None

    result = []

    #
    # Augment the messages with system messages with meta data about which agent is speaking and what materials were available
    #

    # if (message.agent_id != 'user'):
    #    system = f'next message by agent={message.agent_id} with access to materials={[(material.id  if message.materials else "None") for material in message.materials]}'

    if (message.task):
        result.append(GPTMessage(
            role='system',
            name='director',
            content=f'Next task: {message.task}\nAgent: {message.agent_id}\nUse materials: {", ".join(m.id for m in message.materials) if message.materials else "None"}',
        ))

    if (message.code):
        function_call = {
            "name": "execute",
            "arguments": json.dumps({
                "code": message.content,
                "language": message.language,   
            })
        }
        name="execute"
    elif (message.code_output):
        name="output"
    elif (message.agent_id != 'user'):
        name=message.agent_id

    if content:
        result.append(GPTMessage(role=message.role, content=content, function_call=function_call, name=name))

    return result


def convert_messages(messages: List[AICMessage]) -> List[GPTMessage]:
    # Flatten
    return [item for sublist in [convert_message(message) for message in messages] for item in sublist]